"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _crypto = _interopRequireDefault(require("crypto"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const finalize = (salt, hash, encoding) => Buffer.concat([salt, hash]).toString(encoding);

const execute = (options, internalOptions = {}) => {
  const {
    password,
    saltSize,
    iterations,
    encoding,
    algorithm
  } = options;
  let {
    async,
    salt
  } = internalOptions;

  if (!salt) {
    salt = _crypto.default.randomBytes(saltSize);
  }

  if (async) {
    return new Promise((resolve, reject) => {
      _crypto.default.pbkdf2(password, salt, iterations, saltSize, algorithm, (error, hash) => {
        if (error) {
          reject(error);
        } else {
          resolve(finalize(salt, hash, encoding));
        }
      });
    });
  }

  const hash = _crypto.default.pbkdf2Sync(password, salt, iterations, saltSize, algorithm);

  return finalize(salt, hash, encoding);
};

var _default = execute;
exports.default = _default;