"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

var _validate = _interopRequireDefault(require("./validate"));

var _execute = _interopRequireDefault(require("./execute"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const passwordBetterHash = (password, options = {}) => {
  _validate.default.hashInputs(password);

  options = Object.assign({}, _constants.defaults, options, {
    password
  });
  return (0, _execute.default)(options);
};

passwordBetterHash.async = async (password, options = {}) => {
  _validate.default.hashInputs(password);

  options = Object.assign({}, _constants.defaults, options, {
    password
  });
  return (0, _execute.default)(options, {
    async: true
  });
};

passwordBetterHash.compare = (password, hash, options = {}) => {
  _validate.default.compareInputs(password, hash);

  options = Object.assign({}, _constants.defaults, options, {
    password
  });
  let newHash;

  try {
    const {
      encoding,
      saltSize
    } = options;
    const salt = Buffer.from(hash, encoding).slice(0, saltSize);
    newHash = (0, _execute.default)(options, {
      salt
    });
  } catch {
    return false;
  }

  if (hash === newHash) {
    return true;
  }

  return false;
};

passwordBetterHash.compareAsync = async (password, hash, options = {}) => {
  _validate.default.compareInputs(password, hash);

  options = Object.assign({}, _constants.defaults, options, {
    password
  });
  let newHash;

  try {
    const {
      encoding,
      saltSize
    } = options;
    const salt = Buffer.from(hash, encoding).slice(0, saltSize);
    newHash = await (0, _execute.default)(options, {
      salt,
      async: true
    });
  } catch {
    return false;
  }

  if (hash === newHash) {
    return true;
  }

  return false;
};

var _default = passwordBetterHash;
exports.default = _default;